@@ -266,6 +266,7 @@ class PushOptionsBaseten(PushOptions):
     include_git_info: bool
     working_dir: pathlib.Path
     disable_chain_download: bool = False
+    deployment_name: Optional[str] = None
 
     @classmethod
     def create(
@@ -279,6 +280,7 @@ class PushOptionsBaseten(PushOptions):
         working_dir: pathlib.Path,
         environment: Optional[str] = None,
         disable_chain_download: bool = False,
+        deployment_name: Optional[str] = None,
     ) -> "PushOptionsBaseten":
         if promote and not environment:
             environment = PRODUCTION_ENVIRONMENT_NAME
@@ -293,6 +295,7 @@ class PushOptionsBaseten(PushOptions):
             include_git_info=include_git_info,
             working_dir=working_dir,
             disable_chain_download=disable_chain_download,
+            deployment_name=deployment_name,
         )
 
 
