@@ -132,6 +132,7 @@ def create_chain_atomic(
     environment: Optional[str],
     original_source_artifact_s3_key: Optional[str] = None,
     allow_truss_download: bool = True,
+    deployment_name: Optional[str] = None,
 ) -> ChainDeploymentHandleAtomic:
     if environment and is_draft:
         logging.info(
@@ -156,6 +157,7 @@ def create_chain_atomic(
             truss_user_env=truss_user_env,
             original_source_artifact_s3_key=original_source_artifact_s3_key,
             allow_truss_download=allow_truss_download,
+            deployment_name=deployment_name,
         )
     elif chain_id:
         # This is the only case where promote has relevance, since
@@ -171,6 +173,7 @@ def create_chain_atomic(
                 truss_user_env=truss_user_env,
                 original_source_artifact_s3_key=original_source_artifact_s3_key,
                 allow_truss_download=allow_truss_download,
+                deployment_name=deployment_name,
             )
         except ApiError as e:
             if (
@@ -193,6 +196,7 @@ def create_chain_atomic(
             truss_user_env=truss_user_env,
             original_source_artifact_s3_key=original_source_artifact_s3_key,
             allow_truss_download=allow_truss_download,
+            deployment_name=deployment_name,
         )
 
     return ChainDeploymentHandleAtomic(
@@ -397,6 +401,7 @@ def create_truss_service(
     origin: Optional[b10_types.ModelOrigin] = None,
     environment: Optional[str] = None,
     preserve_env_instance_type: bool = True,
+    deploy_timeout_minutes: Optional[int] = None,
 ) -> ModelVersionHandle:
     """
     Create a model in the Baseten remote.
@@ -424,6 +429,7 @@ def create_truss_service(
             truss_user_env,
             allow_truss_download=allow_truss_download,
             origin=origin,
+            deploy_timeout_minutes=deploy_timeout_minutes,
         )
 
         return ModelVersionHandle(
@@ -438,9 +444,6 @@ def create_truss_service(
         )
 
     if model_id is None:
-        if environment and environment != PRODUCTION_ENVIRONMENT_NAME:
-            raise ValueError(NO_ENVIRONMENTS_EXIST_ERROR_MESSAGING)
-
         model_version_json = api.create_model_from_truss(
             model_name,
             s3_key,
@@ -450,6 +453,8 @@ def create_truss_service(
             allow_truss_download=allow_truss_download,
             deployment_name=deployment_name,
             origin=origin,
+            environment=environment,
+            deploy_timeout_minutes=deploy_timeout_minutes,
         )
 
         return ModelVersionHandle(
@@ -474,6 +479,7 @@ def create_truss_service(
             deployment_name=deployment_name,
             environment=environment,
             preserve_env_instance_type=preserve_env_instance_type,
+            deploy_timeout_minutes=deploy_timeout_minutes,
         )
     except ApiError as e:
         if (
