@@ -2099,3 +2099,16 @@ async def test_websocket_ping_timeout_behavior(caplog):
 
         # We wait 3 seconds, so there should be ~3 PING/PONGS
         assert 2 <= caplog.text.count("PING") <= 4
+
+
+@pytest.mark.integration
+def test_build_commands_on_model_files(test_data_path):
+    with ensure_kill_all():
+        truss_dir = test_data_path / "test_build_commands_truss"
+        tr = TrussHandle(truss_dir)
+        container, urls = tr.docker_run_for_test()
+        time.sleep(3)  # Sleeping to allow the load to finish
+
+        response = requests.post(urls.predict_url, json={})
+        assert response.status_code == 200
+        assert response.json() == "TEST_SECOND_VALUE"
