@@ -1,32 +1,43 @@
 import os
-from typing import Dict, Optional
+from typing import Dict, Optional, Set
 
 
-class override_env_vars:
+class modify_env_vars:
     """A context manager for temporarily overwriting environment variables.
 
     Usage:
-        with override_env_vars({'API_KEY': 'test_key', 'DEBUG': 'true'}):
+        with modify_env_vars(overrides={'API_KEY': 'test_key', 'DEBUG': 'true'}, deletions={'AWS_CONFIG_FILE'}):
             # Environment variables are modified here
             ...
         # Original environment is restored here
     """
 
-    def __init__(self, env_vars: Dict[str, str]):
+    def __init__(
+        self,
+        overrides: Optional[Dict[str, str]] = None,
+        deletions: Optional[Set[str]] = None,
+    ):
         """
         Args:
-            env_vars: Dictionary of environment variables to set
+            overrides: Dictionary of environment variables to set
+            deletions: Set of environment variables to delete
         """
-        self.env_vars = env_vars
+        self.overrides: Dict[str, str] = overrides or dict()
+        self.deletions: Set[str] = deletions or set()
         self.original_vars: Dict[str, Optional[str]] = {}
 
     def __enter__(self):
-        for key in self.env_vars:
+        all_keys = set(self.overrides.keys()) | self.deletions
+        for key in all_keys:
             self.original_vars[key] = os.environ.get(key)
 
-        for key, value in self.env_vars.items():
+        for key, value in self.overrides.items():
             os.environ[key] = value
 
+        for key in self.deletions:
+            if key in os.environ:
+                del os.environ[key]
+
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
